@@ -1,6 +1,8 @@
 """
 Command generate-workflow
 """
+import sys
+
 import click
 from tcd_pipeline import pipeline as pipeline_tool
 
@@ -28,3 +30,4 @@ def generate_workflows(pipelines, output):
         )
     except Exception as err:
         print(err)
+        sys.exit(1)
